grib2io.tables.section4_discipline20 API documentation

# grib2io.tables.section4_discipline20

View Source

     1table_4_2_20_0  = {
     2'0':['Universal Thermal Climate Index','K','UTHCIDX'],
     3'1':['Mean Radiant Temperature','K','MEANRTMP'],
     4'2':['Wet-Bulb Globe Temperature','K','WETBGTMP'],
     5'3':['Globe Temperature','K','GLOBETMP'],
     6'4':['Humidex','K','HUMIDX'],
     7'5':['Effective Temperature','K','EFFTEMP'],
     8'6':['Normal Effective Temperature','K','NOREFTMP'],
     9'7':['Standard Effective Temperature','K','STDEFTMP'],
    10'8':['Physiological Equivalent Temperature','K','PEQUTMP'],
    11'9':['UV Biologically Effective Dose','W m-2','UVBED'],
    12'10':['UV Biologically Effective Dose, Clear-Sky','W m-2','UVBEDCS'],
    13'11':['Excess Heat Factor','K2','EHF'],
    14'12':['Excess Cold Factor','K2','ECF'],
    15'13-191':['Reserved','unknown','unknown'],
    16'192-254':['Reserved for Local Use','unknown','unknown'],
    17'255':['Missing','unknown','unknown'],
    18}
    19table_4_2_20_1  = {
    20'0':['Malaria Cases','Fraction','MALACASE'],
    21'1':['Malaria Circumsporozoite Protein Rate','Fraction','MACPRATE'],
    22'2':['Plasmodium Falciparum Entomological Inoculation Rate','Bites per day per person','PFEIRATE'],
    23'3':['Human Bite Rate by Anopheles Vectors','Bites per day per person','HBRATEAV'],
    24'4':['Malaria Immunity','Fraction','MALAIMM'],
    25'5':['Falciparum Parasite Rates','Fraction','FALPRATE'],
    26'6':['Detectable Falciparum Parasite Ratio (after day 10)','Fraction','DFPRATIO'],
    27'7':['Anopheles Vector to Host Ratio','Fraction','AVHRATIO'],
    28'8':['Anopheles Vector Number','Number m-2','AVECTNUM'],
    29'9':['Fraction of Malarial Vector Reproductive Habitat','Fraction','FMALVRH'],
    30'10-191':['Reserved','unknown','unknown'],
    31'192-254':['Reserved for Local Use','unknown','unknown'],
    32'255':['Missing','unknown','unknown'],
    33}
    34table_4_2_20_2  = {
    35'0':['Population Density','Person m-2','POPDEN'],
    36'1-191':['Reserved','unknown','unknown'],
    37'192-254':['Reserved for Local Use','unknown','unknown'],
    38'255':['Missing','unknown','unknown'],
    39}

table_4_2_20_0 = {'0': ['Universal Thermal Climate Index', 'K', 'UTHCIDX'], '1': ['Mean Radiant Temperature', 'K', 'MEANRTMP'], '2': ['Wet-Bulb Globe Temperature', 'K', 'WETBGTMP'], '3': ['Globe Temperature', 'K', 'GLOBETMP'], '4': ['Humidex', 'K', 'HUMIDX'], '5': ['Effective Temperature', 'K', 'EFFTEMP'], '6': ['Normal Effective Temperature', 'K', 'NOREFTMP'], '7': ['Standard Effective Temperature', 'K', 'STDEFTMP'], '8': ['Physiological Equivalent Temperature', 'K', 'PEQUTMP'], '9': ['UV Biologically Effective Dose', 'W m-2', 'UVBED'], '10': ['UV Biologically Effective Dose, Clear-Sky', 'W m-2', 'UVBEDCS'], '11': ['Excess Heat Factor', 'K2', 'EHF'], '12': ['Excess Cold Factor', 'K2', 'ECF'], '13-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_20_1 = {'0': ['Malaria Cases', 'Fraction', 'MALACASE'], '1': ['Malaria Circumsporozoite Protein Rate', 'Fraction', 'MACPRATE'], '2': ['Plasmodium Falciparum Entomological Inoculation Rate', 'Bites per day per person', 'PFEIRATE'], '3': ['Human Bite Rate by Anopheles Vectors', 'Bites per day per person', 'HBRATEAV'], '4': ['Malaria Immunity', 'Fraction', 'MALAIMM'], '5': ['Falciparum Parasite Rates', 'Fraction', 'FALPRATE'], '6': ['Detectable Falciparum Parasite Ratio (after day 10)', 'Fraction', 'DFPRATIO'], '7': ['Anopheles Vector to Host Ratio', 'Fraction', 'AVHRATIO'], '8': ['Anopheles Vector Number', 'Number m-2', 'AVECTNUM'], '9': ['Fraction of Malarial Vector Reproductive Habitat', 'Fraction', 'FMALVRH'], '10-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_20_2 = {'0': ['Population Density', 'Person m-2', 'POPDEN'], '1-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}